@@ -110,15 +110,20 @@
 #' x <- runif(1000, -1, 1)
 #' cov <- rnorm(1000)
 #' y <- 3 + 2 * x + 3 * cov + 10 * (x >= 0) + rnorm(1000)
-#' rd_est(y ~ x)
+#' rd_est(y ~ x, t.design = "geq")
 #' # Efficiency gains can be made by including covariates
-#' rd_est(y ~ x | cov)
+#' rd_est(y ~ x | cov, t.design = "geq")
 
 rd_est <- function(formula, data, subset = NULL, cutpoint = NULL, bw = NULL, 
   kernel = "triangular", se.type = "HC1", cluster = NULL, verbose = FALSE, less = FALSE, 
-  est.cov = FALSE, est.itt = FALSE, t.design = "l") {
+  est.cov = FALSE, est.itt = FALSE, t.design = NULL) {
+  
+  if (is.null(t.design)){
+    stop("Specify t.design.")
+  }
+  
   call <- match.call()
-
+  
   if (missing(data)) 
     data <- environment(formula)
   formula <- as.Formula(formula)
